"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.nspub = void 0;
const { blake2sHex } = require('blakejs');
const fs_1 = __importDefault(require("fs"));
const nodesite_eu_1 = require("nodesite.eu");
const path_1 = __importDefault(require("path"));
const ready = nodesite_eu_1.NodeSiteClient.init();
class nspub {
    static ready(callback) {
        ready.then(callback);
    }
    static async blob(data) {
        const blake = blake2sHex(data);
        const prehash = nspub.hashmap.get(blake);
        if (prehash)
            return prehash;
        return new Promise(resolve => {
            var _a;
            nodesite_eu_1.rawwrite('blake2hash', blake);
            (_a = nodesite_eu_1.direct()) === null || _a === void 0 ? void 0 : _a.once(blake, (hash) => {
                var _a;
                if (hash) {
                    return resolve(hash);
                }
                else {
                    nodesite_eu_1.rawwrite('blob2hash', blake, data);
                    (_a = nodesite_eu_1.direct()) === null || _a === void 0 ? void 0 : _a.once(blake, (hash) => resolve(hash));
                }
            });
        });
    }
    static async file(file) {
        const data = await fs_1.default.promises.readFile(file);
        return await nspub.blob(data);
    }
    static async dir(dir) {
        const read = await fs_1.default.promises.readdir(dir);
        const hashed = await Promise.all(read.map(async (fname) => {
            const pname = path_1.default.resolve(dir, fname);
            const stat = await fs_1.default.promises.stat(pname);
            if (stat.isDirectory()) {
                return `${await nspub.dir(pname)}.html`;
            }
            else if (stat.isFile()) {
                return `${await nspub.file(pname)}/${fname}`;
            }
            else
                return null;
        }));
        let ret = `<h1>${path_1.default.basename(dir)}</h1><ul>`;
        for (let i = 0; i < hashed.length; ++i) {
            i && (ret += `<li><a href="/static/${hashed[i]}">${read[i]}</a></li>`);
        }
        ret += '</ul>';
        return nspub.blob(ret);
    }
}
exports.nspub = nspub;
nspub.hashmap = new Map();
exports.default = nspub;
module.exports = nspub;
Object.assign(nspub, {
    default: nspub,
    nspub,
});
